@@ -94,7 +94,7 @@ def rate_limited_countdown(task: 'HeimdallTask', key):
         return 0
 
     schedule_key = f'{key}.schedule'
-    now = datetime.datetime.now(datetime.timezone.utc)
+    now = datetime.datetime.now(tz=datetime.timezone.utc)
 
     delay = r.get(schedule_key)
     if delay is None or int(delay) < now.timestamp():
@@ -112,10 +112,10 @@ def rate_limited_countdown(task: 'HeimdallTask', key):
     new_time = (
         datetime.datetime.fromtimestamp(
             int(delay),
-            datetime.timezone.utc
+            tz=datetime.timezone.utc
         ) + datetime.timedelta(seconds=per // times)
     )
-    r.set(f'{key}.schedule)', int(new_time.timestamp()))
+    r.set(f'{key}.schedule', int(new_time.timestamp()))
     return int((new_time - now).total_seconds())
 
 
@@ -237,6 +237,10 @@ class HeimdallTask(celery.Task, ABC):
                 # any normal retry limits the user might have set on the
                 # task or globally.
                 self.request.retries -= 1
+                # Max retries needs to be set to None _before_ calling
+                # retry(). This value will not propagate, allowing the user's
+                # normal retry behaviour to apply on the next call.
+                self.max_retries = None
                 raise self.retry(countdown=delay)
 
         return self.run(*args, **kwargs)
